# vito - Vision Tools

Python utilities for common computer vision tasks.

## Dependencies
* `numpy`
* `PIL`

## Examples
TODO

## Changelog
* `0.0.1`
  * Initial public release
  * Contains common python/language and camera projection utils

## TODO List
* flow - read/write/visualize
* pseudocolor
* pvt3 imutils
  * conversion
  * checks (is_valid_bbox, inside image, etc.)
  * camera_projections
* setup
* runner build/test/deploy
* remove python2-specific pyutils
